@@ -7,7 +7,7 @@
 #include <syslog.h>
 
 /* evil static data */
-static int current_log_level = SYNCE_LOG_LEVEL_HIGHEST;
+static int current_log_level = SYNCE_LOG_LEVEL_DEFAULT;
 static bool use_syslog = false;
 
 static int level_to_priority[] =
